#!/bin/sh

#########################################################################################
# function: Update device filesystem from local SD card, cover coresponding files
#           from SD card 'update' directory. (2015-06-30, zqj@HK)
#
# Note: The Update Script, sccUpdate_xxx.sh, should modyfied 'SCRIPT_UPDATE' and script
#       filename for different consumer.
#       for example: sccUpdate_microstar.sh; sccUpdate_eazzydv.sh; sccUpdate_bafu.sh; 
#           sccUpdate_jisiwei.sh, sccUpdate_nasc.sh, and so on.
##########################################################################################

export HOME=/mnt/sif
export PATH=$HOME/bin:/usr/bin:/bin:/usr/sbin:/sbin
export LD_LIBRARY_PATH=/lib:/usr/lib:$HOME/lib

PATH_TMPFS=/tmpfs
PATH_TMP_UPDATE=/tmpfs/update
PATH_SD_UPDATE=/mnt/mmc/FWCHG20-8/update
SCRIPT_UPDATE=$PATH_SD_UPDATE/sccUpdate_bafu.sh
DEV_CURRENT_VER=/mnt/sif/sd_update.version
DEV_MNT_SIF=/mnt/sif
SD_UPDATE_VER=$PATH_SD_UPDATE/sd_update.version


##check version.
func_check_update_version()
{
    echo ">>>>> device current version: `cat $DEV_CURRENT_VER`"
    echo ">>>>> sd card update version: `cat $SD_UPDATE_VER`"
    local version_dev=`grep "VERSION=" $DEV_CURRENT_VER | cut -d= -f2`
    local version_sd=`grep "VERSION=" $SD_UPDATE_VER | cut -d= -f2`

    if [[ $version_dev -ge $version_sd ]]
    then
        echo "note: there is no need to update !!!"      
        return 0;
    else
        echo "note: new version update packets found, it will update your filesystem !"
        return 1;
    fi

    return 0;
}

##copy 'update' from SD card to '/tmpfs/'.
func_do_copy_files()
{
    echo "...$PATH_SD_UPDATE ===> $PATH_TMPFS..."
    cp -r $PATH_SD_UPDATE $PATH_TMPFS
    sleep 1
    sync

    if [ ! -d $PATH_TMP_UPDATE ]
    then
        echo "copy $PATH_SD_UPDATE failed !"
        return 0
    else
        echo "copy success, tmp dir:$PATH_TMP_UPDATE"
        ls $PATH_TMP_UPDATE
        return 1 #tmp dir copy for update existed.
    fi

    return 0;
}

##check dir existence.
func_check_update_packets_exist()
{
    echo "==>sd update path: $PATH_SD_UPDATE"
    if [ ! -d $PATH_SD_UPDATE ]
    then
        echo "$PATH_SD_UPDATE is not existed !!!"
        return 0
    else ##dir existed, copy for update.
        echo "$DEV_CURRENT_VER"
        echo "$SD_UPDATE_VER"
        if [ -f $SD_UPDATE_VER ] ##version files existed.
        then
            func_check_update_version
            version_result=$?
            echo "version_result: $version_result"
            if [ 1 -eq $version_result ] #sd version grater than current device version.
            then
                func_do_copy_files
                copy_result=$?
                echo "copy_result: $copy_result"
                if [ 1 -eq $copy_result ]
                then
                    return 1;
                fi
            fi
        fi
    fi
    
    return 0;
}

##delete unused sensor lib.
func_delete_unused_src()
{
    ls -l /usr/lib/libsns_*
    chmod 777 /usr/lib/libsns_*
    rm /usr/lib/libsns_himax1375.so
    #rm /usr/lib/libsns_imx*
}

##cover new files from SD card to device filesystem.
func_do_scc_update()
{
    if [ -f "$PATH_TMP_UPDATE/fstab" ]
    then
        mv $PATH_TMP_UPDATE/fstab /etc/
    fi

    if [ -f "$PATH_TMP_UPDATE/RT2870AP.dat" ]
    then
        mv $PATH_TMP_UPDATE/RT2870AP.dat /etc/Wireless/RT2870AP/
    fi
    
    if [ -f "$PATH_TMP_UPDATE/hkipc.conf" ]
    then
        mv $PATH_TMP_UPDATE/hkipc.conf /mnt/sif/
    fi

    if [ -f "$PATH_TMP_UPDATE/udhcpd.conf" ]
    then
        mv $PATH_TMP_UPDATE/udhcpd.conf /mnt/sif/
	chmod 755 /mnt/sif/udhcpd.conf
    fi

    if [ -f "$PATH_TMP_UPDATE/CKRate" ]
    then
        mv $PATH_TMP_UPDATE/CKRate /mnt/sif/bin/

	chmod 755 /mnt/sif/bin/CKRate
        mv $PATH_TMP_UPDATE/IPRate.conf /mnt/sif/
	chmod 755 /mnt/sif/IPRate.conf
    fi

    if [ -f "$PATH_TMP_UPDATE/8188eu.ko" ]
    then
        mv $PATH_TMP_UPDATE/8188eu.ko /komod/

        mv $PATH_TMP_UPDATE/hostapd /usr/bin/
        mv $PATH_TMP_UPDATE/iwconfig /usr/bin/
        mv $PATH_TMP_UPDATE/iwlist /usr/bin/
        mv $PATH_TMP_UPDATE/iwpriv /usr/bin/

	chmod 755 /usr/bin/*
        mv $PATH_TMP_UPDATE/wifi_connect.sh /mnt/sif/bin/
        mv $PATH_TMP_UPDATE/hostapd.conf /mnt/sif/
        mv $PATH_TMP_UPDATE/udhcpd.conf /mnt/sif/

    fi

    if [ -f "$PATH_TMP_UPDATE/libnetfactory.so" ]
    then
        mv $PATH_TMP_UPDATE/libnetfactory.so /mnt/sif/lib/
    fi

    if [ -f "$PATH_TMP_UPDATE/libchinalink.so" ]
    then
        mv $PATH_TMP_UPDATE/libchinalink.so /mnt/sif/lib/
    fi

    if [ -f "$PATH_TMP_UPDATE/libutils.so" ]
    then
	cp $PATH_TMP_UPDATE/libutils.so /usr/lib/
        mv $PATH_TMP_UPDATE/libutils.so /mnt/sif/lib/
    fi

    if [ -f "$PATH_TMP_UPDATE/S50network" ]
    then
        mv $PATH_TMP_UPDATE/S50network /etc/init.d/S50network
	chmod 755 /etc/init.d/S50network
    fi

    if [ -f "$PATH_TMP_UPDATE/S09tmpfs" ]
    then
        mv $PATH_TMP_UPDATE/S09tmpfs /etc/init.d/
    fi

    if [ -f "$PATH_TMP_UPDATE/S10mpp" ]
    then
        mv $PATH_TMP_UPDATE/S10mpp /etc/init.d/
    fi

    if [ -f "$PATH_TMP_UPDATE/S50network" ]
    then
        mv $PATH_TMP_UPDATE/S50network /etc/init.d/
    fi

    if [ -f "$PATH_TMP_UPDATE/S60hkp2p" ]
    then
        mv $PATH_TMP_UPDATE/S60hkp2p /etc/init.d/
    fi

    if [ -f "$PATH_TMP_UPDATE/S70crontab" ]
    then
        mv $PATH_TMP_UPDATE/S70crontab /etc/init.d/
    fi

    if [ -d "$PATH_TMP_UPDATE/Wireless" ]
    then
        rm -rf /etc/Wireless
        mv $PATH_TMP_UPDATE/Wireless /etc/
    fi

    if [ -d "$PATH_TMP_UPDATE/wifiConf" ]
    then
        rm -rf /etc/wifiConf
        mv $PATH_TMP_UPDATE/wifiConf /etc/
    fi

    if [ -f "$PATH_TMP_UPDATE/sensorenv.sh" ]
    then
        mv $PATH_TMP_UPDATE/sensorenv.sh /komod/
    fi

    if [ -f "$PATH_TMP_UPDATE/setgpio.sh" ]
    then
        mv $PATH_TMP_UPDATE/setgpio.sh /komod/
    fi

    if [ -f "$PATH_TMP_UPDATE/iwpriv.tar" ]
    then
        tar -xvf $PATH_TMP_UPDATE/iwpriv.tar -C /lib/
        usleep 1000
        mv /lib/iwpriv /bin/
        rm $PATH_TMP_UPDATE/iwpriv.tar
    fi

    if [ -f "$PATH_TMP_UPDATE/write_norflash_tool" ]
    then
        mv $PATH_TMP_UPDATE/write_norflash_tool /bin/
    fi

    if [ -f "$PATH_TMP_UPDATE/libstdc++.so.6.0.12" ]
    then
        mv $PATH_TMP_UPDATE/libstdc++.so.6.0.12 /lib/
        ln -s /lib/libstdc++.so.6.0.12 /lib/libstdc++.so
        ln -s /lib/libstdc++.so.6.0.12 /lib/libstdc++.so.6
    fi

    if [ -f "$PATH_TMP_UPDATE/onvif.tgz" ]
    then
        tar -xvf $PATH_TMP_UPDATE/onvif.tgz -C /usr/lib/
        usleep 1000
        rm $PATH_TMP_UPDATE/onvif.tgz
    fi

    if [ -f "$PATH_TMP_UPDATE/wire_connect.sh" ]
    then
        rm -rf $PATH_TMP_UPDATE/wireless
        mv $PATH_TMP_UPDATE/wire_connect.sh /mnt/sif/bin/
        mv $PATH_TMP_UPDATE/wifi_connect.sh /mnt/sif/bin/
    fi

    if [ -f "$PATH_TMP_UPDATE/www_hk.tar.gz" ]
    then
        tar -xvf $PATH_TMP_UPDATE/www_hk.tar.gz -C /mnt/sif/bin/
        usleep 1000
        rm $PATH_TMP_UPDATE/www_hk.tar.gz
    fi

    if [ -f "$PATH_TMP_UPDATE/hkipc" ]
    then
        killall -9 hkipc
        mv $PATH_TMP_UPDATE/hkipc /mnt/sif/bin/
    fi

    if [ -f "$PATH_TMP_UPDATE/globefish" ]
    then
        killall -9 globefish
        mv $PATH_TMP_UPDATE/globefish /mnt/sif/bin/
    fi
    echo "......do scc update ok......"
}


###
### main:
###
echo "*********************************************************"
echo "****************** BAFU SD update ********************"
echo "*********************************************************"
func_delete_unused_src ##delete unused lib.

func_check_update_packets_exist
check_result=$?
echo "check_result: $check_result"
if [ 1 -eq $check_result ] #dir existed.
then
    /mnt/mmc/FWCHG20-8/updateLED_* & ##LED notify for update.
    /mnt/sif/bin/runhkipc stop #stop ipc proc services.
    killall crond
    usleep 1000
    rmmod wdt #remove WatchDog module.
    killall globefish #stop network service.
    sync
    echo "================> SCC Update System From SD Card Now <================="
    func_do_scc_update
    sleep 1
    mv $PATH_TMP_UPDATE/sd_update.version $DEV_MNT_SIF
    sync
    echo ">>>>>>>>>> device new version: `cat $DEV_CURRENT_VER`"
    echo "...... 3518E update from Local SD card success, System reboot now ......\n"
    reboot
else
    echo "Dir is not existed, do nothing !!!"
    exit 0
fi

